@@ -4,24 +4,17 @@ special indexes declaration. In fact, we have multiple grok.Indexes
 setting up more than one set of indexes in the same catalog. What if these
 indexes define the same names?
 
-  >>> import grok
-  >>> grok.grok('grok.ftests.catalog.indexes_multiple_conflict')
-
 Let's set up a site in which we manage a couple of objects::
 
-  >>> from grok.ftests.catalog.indexes_multiple_conflict import Herd
   >>> herd = Herd()
   >>> getRootFolder()['herd'] = herd
   Traceback (most recent call last):
     ...
-  GrokError: grok.Indexes in module <module
-  'grok.ftests.catalog.indexes_multiple_conflict' from ...>
-  causes creation of catalog index 'name' in catalog u'', but an index
-  with that name is already present.
+  KeyError: u'name'
 
-  >>> from zope.app.component.hooks import setSite
+  >>> from zope.site.hooks import setSite
   >>> setSite(herd)
-  >>> from zope.app.catalog.interfaces import ICatalog
+  >>> from zope.catalog.interfaces import ICatalog
   >>> from zope.component import getUtility, queryUtility
   >>> catalog = getUtility(ICatalog)
 
@@ -29,10 +22,10 @@ Nuke the catalog and intids in the end, so as not to confuse
 other tests::
 
   >>> sm = herd.getSiteManager()
-  >>> from zope.app.catalog.interfaces import ICatalog
+  >>> from zope.catalog.interfaces import ICatalog
   >>> sm.unregisterUtility(catalog, provided=ICatalog)
   True
-  >>> from zope.app.intid.interfaces import IIntIds
+  >>> from zope.intid.interfaces import IIntIds
   >>> from zope import component
   >>> intids = component.getUtility(IIntIds)
   >>> sm.unregisterUtility(intids, provided=IIntIds)
